@@ -179,6 +179,27 @@ void keyPressed(unsigned char key, int x, int y)
 			freenect_angle = -30;
 		}
 	}
+	if (key == 'e') {
+		static freenect_flag_value auto_exposure = FREENECT_ON;
+		freenect_set_flag(f_dev, FREENECT_AUTO_EXPOSURE, auto_exposure);
+		auto_exposure = !auto_exposure;
+	}
+	if (key == 'b') {
+		static freenect_flag_value white_balance = FREENECT_ON;
+		freenect_set_flag(f_dev, FREENECT_AUTO_WHITE_BALANCE, white_balance);
+		white_balance = !white_balance;
+	}
+	if (key == 'r') {
+		static freenect_flag_value raw_color = FREENECT_ON;
+		freenect_set_flag(f_dev, FREENECT_RAW_COLOR, raw_color);
+		raw_color = !raw_color;
+	}
+	if (key == 'm') {
+		static freenect_flag_value mirror = FREENECT_ON;
+		freenect_set_flag(f_dev, FREENECT_MIRROR_DEPTH, mirror);
+		freenect_set_flag(f_dev, FREENECT_MIRROR_VIDEO, mirror);
+		mirror = !mirror;
+	}
 	if (key == '1') {
 		freenect_set_led(f_dev,LED_GREEN);
 	}
@@ -349,6 +370,7 @@ void *freenect_threadfunc(void *arg)
 	freenect_start_video(f_dev);
 
 	printf("'w'-tilt up, 's'-level, 'x'-tilt down, '0'-'6'-select LED mode, 'f'-video format\n");
+	printf("'e' - auto exposure, 'b' - white balance, 'r' - raw color, 'm' - mirror\n");
 
 	while (!die && freenect_process_events(f_ctx) >= 0) {
 		//Throttle the text output
@@ -421,17 +443,21 @@ int main(int argc, char **argv)
 	if (argc > 1)
 		user_device_number = atoi(argv[1]);
 
-	if (nr_devices < 1)
+	if (nr_devices < 1) {
+		freenect_shutdown(f_ctx);
 		return 1;
+	}
 
 	if (freenect_open_device(f_ctx, &f_dev, user_device_number) < 0) {
 		printf("Could not open device\n");
+		freenect_shutdown(f_ctx);
 		return 1;
 	}
 
 	res = pthread_create(&freenect_thread, NULL, freenect_threadfunc, NULL);
 	if (res) {
 		printf("pthread_create failed\n");
+		freenect_shutdown(f_ctx);
 		return 1;
 	}
 
