@@ -24,8 +24,7 @@
  * either License.
  */
 
-#ifndef SERVER_JPEG_H
-#define SERVER_JPEG_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -40,5 +39,3 @@ int RGB_2_JPEG(unsigned char *buffer, unsigned char **compressed, long unsigned
 #ifdef __cplusplus
 }
 #endif
-
-#endif
\ No newline at end of file
